## Version 0.5.3

This release includes updates to the commit message format and documentation, as well as dependency updates.

### New Features

- The description length limit for commit messages has been increased from 79 characters to 160 characters, and the body length limit has been increased from 6 entries to 10 entries. (cc1f9bd, Eric Ma)

### Bug Fixes

- The `pixi` lockfile has been updated. (cf66961, Eric Ma)
- The `chatbot_nb.ipynb` file has been updated. (c354319, Eric Ma)

### Deprecations

- None in this release.
